==> enterprisemodules-ora_config-3.18.3.tar.gz: enterprisemodules-ora_config-3.18.3/lib/puppet/type/ora_home_option.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'easy_type/helpers'
require 'puppet_x/enterprisemodules/oracle/title_parser'

module Puppet
  #
  Type.newtype(:ora_home_option) do
    include EasyType
    include EasyType::Helpers
    extend Puppet_X::EnterpriseModules::Oracle::TitleParser

    desc <<-EOD

      This resource allows you to manage(enable/disable) options in an Oracle database home.

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            datamining               => 'disabled',
            direct_nfs               => 'disabled',
            olap                     => 'disabled',
            partitioning             => 'disabled',
            real_application_testing => 'disabled',
          }

    EOD

    to_get_raw_resources do
      ora_install_homes = Facter::value('ora_install_homes') || {}
      homes = ora_install_homes.keys.select { |h| ora_install_homes[h]['name'] !~ /agent/i }
      homes.collect do |home|
        entry = {}
        entry['NAME'] = home
        options = { :failonfail => true, :combine => true }
        os_user = ora_install_homes.dig(home, 'os_user').nil? ? 'oracle' : ora_install_homes.dig(home, 'os_user')
        result = Puppet::Util::Execution.execute("su - #{os_user} -c \"ar -t #{home}/rdbms/lib/libknlopt.a\"", options).split(/\n/)
        dnfs_result = Puppet::Util::Execution.execute("su - #{os_user} -c \"if ls #{home}/rdbms/lib/odm/libnfsodm??.so 2>&1 > /dev/null; then echo libnfsodm.so; else echo libnonfsodm.so; fi\"", options).split(/\n/)
        all_results = result + dnfs_result
        db_options = ['DM', 'OAA', 'OLAP', 'PART', 'RAT', 'DNFS', 'UNIAUD']
        db_options.collect do |option|
          if option == 'DM' or option == 'OAA'
            lib = all_results.select { |x| x =~ /dmndm.o|dmwdm.o/ }.first
            entry[option] = lib == 'dmndm.o' ? 'disabled' : 'enabled'
          elsif option == 'OLAP'
            lib = all_results.select { |x| x =~ /xsnoolap.o|xsyeolap.o/ }.first
            entry['OLAP'] = lib == 'xsnoolap.o' ? 'disabled' : 'enabled'
          elsif option == 'PART'
            lib = all_results.select { |x| x =~ /ksnkkpo.o|kkpoban.o/ }.first
            entry['PART'] = lib == 'ksnkkpo.o' ? 'disabled' : 'enabled'
          elsif option == 'RAT'
            lib = all_results.select { |x| x =~ /kecnr.o|kecwr.o/ }.first
            entry['RAT'] = lib == 'kecnr.o' ? 'disabled' : 'enabled'
          elsif option == 'DNFS'
            lib = all_results.select { |x| x =~ /libnonfsodm.so|libnfsodm.so/ }.first
            entry['DNFS'] = lib == 'libnonfsodm.so' ? 'disabled' : 'enabled'
          elsif option == 'UNIAUD'
            lib = all_results.select { |x| x =~ /kzanang.o|kzaiang.o/ }.first
            entry['UNIAUD'] = lib == 'kzanang.o' ? 'disabled' : 'enabled'
          end
        end
        entry
      end
    end

    on_create do
      nil
    end

    on_modify do
      # Allow individual properties to do their stuff
    end

    on_destroy do
      nil
    end

    map_title_to_sid(:name)

    parameter :name
    property  :advanced_analytics
    property  :datamining
    property  :olap
    property  :partitioning
    property  :direct_nfs
    property  :real_application_testing
    property  :unified_auditing

  end
end

==> enterprisemodules-ora_config-3.18.4.tar.gz: enterprisemodules-ora_config-3.18.4/lib/puppet/type/ora_home_option.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'easy_type/helpers'
require 'puppet_x/enterprisemodules/oracle/title_parser'

# rubocop:disable Style/Documentation
module Puppet
  # rubocop:enable Style/Documentation
  Type.newtype(:ora_home_option) do
    include EasyType
    include EasyType::Helpers
    extend Puppet_X::EnterpriseModules::Oracle::TitleParser

    desc <<-DESC

      This resource allows you to manage(enable/disable) options in an Oracle database home.

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            datamining               => 'disabled',
            direct_nfs               => 'disabled',
            olap                     => 'disabled',
            partitioning             => 'disabled',
            real_application_testing => 'disabled',
          }

    DESC

    to_get_raw_resources do
      ora_install_homes = Facter.value('ora_install_homes') || {}
      homes = ora_install_homes.keys.reject { |h| ora_install_homes[h]['name'] =~ /agent/i }
      homes.collect do |home|
        entry = {}
        entry['NAME'] = home
        options = { :failonfail => true, :combine => true }
        os_user = ora_install_homes.dig(home, 'os_user').nil? ? 'oracle' : ora_install_homes.dig(home, 'os_user')
        result = Puppet::Util::Execution.execute("su - #{os_user} -c \"ar -t #{home}/rdbms/lib/libknlopt.a\"", options).split(/\n/)
        dnfs_result = Puppet::Util::Execution.execute("su - #{os_user} -c \"if ls #{home}/rdbms/lib/odm/libnfsodm??.so 2>&1 > /dev/null; then echo libnfsodm.so; else echo libnonfsodm.so; fi\"",
                                                      options).split(/\n/)
        all_results = result + dnfs_result
        db_options = %w[DM OAA OLAP PART RAT DNFS UNIAUD]
        db_options.collect do |option|
          if %w[DM OAA].include?(option)
            lib = all_results.find { |x| x =~ /dmndm.o|dmwdm.o/ }
            entry[option] = lib == 'dmndm.o' ? 'disabled' : 'enabled'
          elsif option == 'OLAP'
            lib = all_results.find { |x| x =~ /xsnoolap.o|xsyeolap.o/ }
            entry['OLAP'] = lib == 'xsnoolap.o' ? 'disabled' : 'enabled'
          elsif option == 'PART'
            lib = all_results.find { |x| x =~ /ksnkkpo.o|kkpoban.o/ }
            entry['PART'] = lib == 'ksnkkpo.o' ? 'disabled' : 'enabled'
          elsif option == 'RAT'
            lib = all_results.find { |x| x =~ /kecnr.o|kecwr.o/ }
            entry['RAT'] = lib == 'kecnr.o' ? 'disabled' : 'enabled'
          elsif option == 'DNFS'
            lib = all_results.find { |x| x =~ /libnonfsodm.so|libnfsodm.so/ }
            entry['DNFS'] = lib == 'libnonfsodm.so' ? 'disabled' : 'enabled'
          elsif option == 'UNIAUD'
            lib = all_results.find { |x| x =~ /kzanang.o|kzaiang.o/ }
            entry['UNIAUD'] = lib == 'kzanang.o' ? 'disabled' : 'enabled'
          end
        end
        entry
      end
    end

    on_create do
      nil
    end

    on_modify do
      # Allow individual properties to do their stuff
    end

    on_destroy do
      nil
    end

    map_title_to_sid(:name)

    parameter :name
    property  :advanced_analytics
    property  :datamining
    property  :olap
    property  :partitioning
    property  :direct_nfs
    property  :real_application_testing
    property  :unified_auditing
  end
end
